node

package
v1.2.0 Latest Latest
Warning

This package is not in the latest version of its module.

Go to latest
Published: Apr 22, 2026 License: Apache-2.0 Imports: 4 Imported by: 0

Documentation

Overview

Package node provides utilities for resolving cloud provider instance IDs to Kubernetes Nodes.

Index

Constants

This section is empty.

Variables

This section is empty.

Functions

func FindByProviderID

func FindByProviderID(ctx context.Context, c client.Client, providerInstanceID string) (*corev1.Node, error)

FindByProviderID finds a node by matching the provider instance ID within the providerID field.

func MatchesProviderID

func MatchesProviderID(nodeProviderID, providerInstanceID string) bool

MatchesProviderID checks if the provider instance ID matches the node's providerID. Handles cloud-specific providerID formats:

  • AWS: aws:///us-west-2a/i-1234567890abcdef0
  • GCP: gce://project/zone/instance-name

Types

This section is empty.

Jump to