Documentation
¶
Overview ¶
Package renewal provides operator client certificate renewal logic for long-running processes.
Index ¶
Constants ¶
This section is empty.
Variables ¶
This section is empty.
Functions ¶
Types ¶
type CertificateStore ¶
CertificateStore stores renewed certificates.
type Config ¶
type Config struct {
CurrentCert *x509.Certificate
PrivateKey ed25519.PrivateKey
Store CertificateStore
Connections ConnectionProvider
Logger *slog.Logger
}
Config holds the configuration for certificate renewal.
type ConnectionProvider ¶
type ConnectionProvider interface {
// GetConnection returns a gRPC connection to any available shard.
// It may establish a new connection or return an existing one.
GetConnection(ctx context.Context) (conn *grpc.ClientConn, shard string, err error)
}
ConnectionProvider provides a gRPC connection to a shard for renewal.
Click to show internal directories.
Click to hide internal directories.